#ifndef GLMMGS_STANDARD_H
#define GLMMGS_STANDARD_H

#include "../Utilities/Utilities.h"
#include "../Utilities/Exceptions/Exceptions.h"
#include "../Utilities/IO/IO.h"
#include "../Utilities/LinearAlgebra/LinearAlgebra.h"
#include "../Utilities/Math/Math.h"
#include "../Utilities/Statistics/StatisticFunctions.h"
#include "../Utilities/LDL/LDL.h"
#include "../Utilities/NewTypes/NewTypes.h"

namespace GlmmGS
{
	using namespace Utilities;
	using namespace Utilities::Exceptions;
	using namespace Utilities::IO;
	using namespace Utilities::LinearAlgebra;
	using namespace Utilities::Math;
	using namespace Utilities::Statistics;
}

#endif
